==> physx-jni-0.3.2-sources.jar: physx/physics/PxSweepQueryResult.java <==
package physx.physics;

import physx.NativeObject;

public class PxSweepQueryResult extends NativeObject {

    protected PxSweepQueryResult() { }

    public static PxSweepQueryResult wrapPointer(long address) {
        return new PxSweepQueryResult(address);
    }
    
    protected PxSweepQueryResult(long address) {
        super(address);
    }

    // Destructor

    public void destroy() {
        if (address == 0L) {
            throw new IllegalStateException(this + " is already deleted");
        }
        if (isStackAllocated) {
            throw new IllegalStateException(this + " is stack allocated and cannot be deleted");
        }
        _delete_native_instance(address);
        address = 0L;
    }
    private static native long _delete_native_instance(long address);

    // Attributes

    /**
     * @return {@link PxSweepHit} [Value]
     */
    public PxSweepHit getBlock() {
        return PxSweepHit.wrapPointer(_getBlock(address));
    }
    private static native long _getBlock(long address);

    /**
     * @param value {@link PxSweepHit} [Value]
     */
    public void setBlock(PxSweepHit value) {
        _setBlock(address, value.getAddress());
    }
    private static native void _setBlock(long address, long value);

    /**
     * @return {@link PxSweepHit}
     */
    public PxSweepHit getTouches() {
        return PxSweepHit.wrapPointer(_getTouches(address));
    }
    private static native long _getTouches(long address);

    /**
     * @param value {@link PxSweepHit}
     */
    public void setTouches(PxSweepHit value) {
        _setTouches(address, value.getAddress());
    }
    private static native void _setTouches(long address, long value);

    /**
     * @return unsigned long
     */
    public int getNbTouches() {
        return _getNbTouches(address);
    }
    private static native int _getNbTouches(long address);

    /**
     * @param value unsigned long
     */
    public void setNbTouches(int value) {
        _setNbTouches(address, value);
    }
    private static native void _setNbTouches(long address, int value);

    /**
     * @return any
     */
    public NativeObject getUserData() {
        return NativeObject.wrapPointer(_getUserData(address));
    }
    private static native long _getUserData(long address);

    /**
     * @param value any
     */
    public void setUserData(NativeObject value) {
        _setUserData(address, value.getAddress());
    }
    private static native void _setUserData(long address, long value);

    /**
     * @return octet
     */
    public byte getQueryStatus() {
        return _getQueryStatus(address);
    }
    private static native byte _getQueryStatus(long address);

    /**
     * @param value octet
     */
    public void setQueryStatus(byte value) {
        _setQueryStatus(address, value);
    }
    private static native void _setQueryStatus(long address, byte value);

    /**
     * @return boolean
     */
    public boolean getHasBlock() {
        return _getHasBlock(address);
    }
    private static native boolean _getHasBlock(long address);

    /**
     * @param value boolean
     */
    public void setHasBlock(boolean value) {
        _setHasBlock(address, value);
    }
    private static native void _setHasBlock(long address, boolean value);

    // Functions

    /**
     * @return unsigned long
     */
    public int getNbAnyHits() {
        return _getNbAnyHits(address);
    }
    private static native int _getNbAnyHits(long address);

    /**
     * @param index unsigned long
     * @return {@link PxSweepHit} [Const, Ref]
     */
    public PxSweepHit getAnyHit(int index) {
        return PxSweepHit.wrapPointer(_getAnyHit(address, index));
    }
    private static native long _getAnyHit(long address, int index);

}

==> physx-jni-0.4.0-sources.jar: physx/physics/PxSweepQueryResult.java <==
package physx.physics;

import physx.NativeObject;

public class PxSweepQueryResult extends NativeObject {

    protected PxSweepQueryResult() { }

    public static PxSweepQueryResult wrapPointer(long address) {
        return new PxSweepQueryResult(address);
    }
    
    protected PxSweepQueryResult(long address) {
        super(address);
    }

    // Destructor

    public void destroy() {
        if (address == 0L) {
            throw new IllegalStateException(this + " is already deleted");
        }
        if (isExternallyAllocated) {
            throw new IllegalStateException(this + " is externally allocated and cannot be manually destroyed");
        }
        _delete_native_instance(address);
        address = 0L;
    }
    private static native long _delete_native_instance(long address);

    // Attributes

    /**
     * @return WebIDL type: {@link PxSweepHit} [Value]
     */
    public PxSweepHit getBlock() {
        return PxSweepHit.wrapPointer(_getBlock(address));
    }
    private static native long _getBlock(long address);

    /**
     * @param value WebIDL type: {@link PxSweepHit} [Value]
     */
    public void setBlock(PxSweepHit value) {
        _setBlock(address, value.getAddress());
    }
    private static native void _setBlock(long address, long value);

    /**
     * @return WebIDL type: {@link PxSweepHit}
     */
    public PxSweepHit getTouches() {
        return PxSweepHit.wrapPointer(_getTouches(address));
    }
    private static native long _getTouches(long address);

    /**
     * @param value WebIDL type: {@link PxSweepHit}
     */
    public void setTouches(PxSweepHit value) {
        _setTouches(address, value.getAddress());
    }
    private static native void _setTouches(long address, long value);

    /**
     * @return WebIDL type: unsigned long
     */
    public int getNbTouches() {
        return _getNbTouches(address);
    }
    private static native int _getNbTouches(long address);

    /**
     * @param value WebIDL type: unsigned long
     */
    public void setNbTouches(int value) {
        _setNbTouches(address, value);
    }
    private static native void _setNbTouches(long address, int value);

    /**
     * @return WebIDL type: any
     */
    public NativeObject getUserData() {
        return NativeObject.wrapPointer(_getUserData(address));
    }
    private static native long _getUserData(long address);

    /**
     * @param value WebIDL type: any
     */
    public void setUserData(NativeObject value) {
        _setUserData(address, value.getAddress());
    }
    private static native void _setUserData(long address, long value);

    /**
     * @return WebIDL type: octet
     */
    public byte getQueryStatus() {
        return _getQueryStatus(address);
    }
    private static native byte _getQueryStatus(long address);

    /**
     * @param value WebIDL type: octet
     */
    public void setQueryStatus(byte value) {
        _setQueryStatus(address, value);
    }
    private static native void _setQueryStatus(long address, byte value);

    /**
     * @return WebIDL type: boolean
     */
    public boolean getHasBlock() {
        return _getHasBlock(address);
    }
    private static native boolean _getHasBlock(long address);

    /**
     * @param value WebIDL type: boolean
     */
    public void setHasBlock(boolean value) {
        _setHasBlock(address, value);
    }
    private static native void _setHasBlock(long address, boolean value);

    // Functions

    /**
     * @return WebIDL type: unsigned long
     */
    public int getNbAnyHits() {
        return _getNbAnyHits(address);
    }
    private static native int _getNbAnyHits(long address);

    /**
     * @param index WebIDL type: unsigned long
     * @return WebIDL type: {@link PxSweepHit} [Const, Ref]
     */
    public PxSweepHit getAnyHit(int index) {
        return PxSweepHit.wrapPointer(_getAnyHit(address, index));
    }
    private static native long _getAnyHit(long address, int index);

}
